from distutils.core import setup
setup(
  name = 'cityhall',
  packages = ['cityhall'], # this must be the same as the name above
  version = '0.0.5',
  description = 'A library for accessing City Hall Setting Server',
  author = 'Alex Popa',
  author_email = 'alexpopa@digitalborderlands.com',
  url = 'https://github.com/f00f-nyc/cityhall-python',
  download_url = 'https://codeload.github.com/f00f-nyc/cityhall-python/legacy.tar.gz/v0.0.5',
  keywords = ['cityhall', 'enterprise', 'cityhall', 'City Hall'],
  classifiers = [],
)